<?php

// @ini_set('display_errors', 1);
// error_reporting(E_ALL);

require_once('../../bootstrap.php');

$oModuleController = new Kad_Module_Controller(1337);
$sModuleName = $oModuleController->get('internal_name');
$sModuleVersion = $oModuleController->get('version');
$sTitle = $oModuleController->get('client_name');
$site = $oModuleController->get('module_site');

Core_Auth::authorization($sModuleName);

$sAdminModuleDir = '/admin/' . $sModuleName;
$sAdminFormAction = '/admin/' . $sModuleName . '/index.php';

// Форма
$oAdminForm = Core_Entity::factory('Admin_Form', $oModuleController->get('admin_form'));

// Контроллер формы
$oAdminFormController = Admin_Form_Controller::create($oAdminForm);
$oAdminFormController
	->module(Core_Module::factory($sModuleName))
	->setUp()
	->path($sAdminFormAction)
	->title($sTitle)
	->pageTitle($sTitle);

// Действие «Сформировать»
$oAction = $oAdminForm
	->Admin_Form_Actions
	->getByName('process');

if ($oAction && $oAdminFormController->getAction() == 'process')
{
	Core_Event::attach('Admin_Form_Controller.onBeforeExecute',
		function ($oAdminFormController)
		{
			$aoShopOrders = array();
			foreach ($oAdminFormController->getChecked() as $datasetKey => $checkedItems)
			{
				foreach ($checkedItems as $checkedItemId => $v1)
				{
					$aoShopOrders[] = $oAdminFormController->getDataset($datasetKey)->getObject($checkedItemId);
				}
			}

			try
			{
				$oDeliverystickersController = new Deliverystickers_Controller($aoShopOrders);
				$stickersPath = $oDeliverystickersController->create();

				$oAdminFormController->addMessage(
					Core_Message::get(
						sprintf('Файл с этикетками успешно сгенерирован, вы можете скачать его по следующей сслыке: <a href="%s" target="_blank">%s</a>.',
							$stickersPath,
							$stickersPath
						)
					)
				);
			}
			catch (Exception $e)
			{
				$oAdminFormController->addMessage(Core_Message::get($e->getMessage(), 'error'));
			}
		});

	$oProcessAction = Admin_Form_Action_Controller::factory(
		'Deliverystickers_Controller_Process', $oAction
	);

	$oAdminFormController->addAction($oProcessAction);
}

// Меню
$oAdminFormController
	->addEntity(
		Admin_Form_Entity::factory('Menus')
			->add(
				Admin_Form_Entity::factory('Menu')
					->name('Вызвать курьера')
					->icon('fa fa-phone')
					->href(
						$oAdminFormController->getAdminLoadHref('/admin/deliverystickers/courier/index.php')
					)
					->onclick(
						$oAdminFormController->getAdminLoadAjax('/admin/deliverystickers/courier/index.php')
					)
			)
	);

// Магазины
$aoShops = Core_Entity::factory('Site', CURRENT_SITE)->Shops->findAll();

$aShopIds = array();
foreach ($aoShops as $oShop)
{
	$aShopIds[] = $oShop->id;
}

// Источник данных
$oAdminFormDataset = new Admin_Form_Dataset_Entity(Core_Entity::factory('Shop_Order'));

if (count($aShopIds))
{
	$oAdminFormDataset->addCondition(
		array('where' =>
			array('shop_id', 'IN', $aShopIds)
		)
	);

	// TIP: Ограничиваем список заказов только оплаченными
	$oAdminFormDataset->addCondition(
		array('where' =>
			array('paid', '=', '1')
		)
	);

	// TIP: Ограничиваем список заказов только с доставкой Pickpoint
	$oAdminFormDataset->addCondition(
		array('where' =>
			array('shop_delivery_id', 'IN', array(6))
		)
	);
}
else
{
	$oAdminFormDataset->addCondition(
		array('limit' => 0)
	);
}

// Добавляем источник данных контроллеру формы
$oAdminFormController->addDataset(
	$oAdminFormDataset
);

// Показ формы
$oAdminFormController->execute();