<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

class Deliverystickers_Courier_Controller
{
	protected $_apiUrl;
	protected $_apiLogin;
	protected $_apiPassword;
	protected $_apiIkn;
	protected $_apiTimeout;

	public function __construct()
	{
		$this->_apiTimeout = 2;

		$aConfig = Core_Config::instance()->get('deliverystickers_config', array());

		$this->_apiUrl = Core_Array::get($aConfig, 'url');
		$this->_apiLogin = Core_Array::get($aConfig, 'login');
		$this->_apiPassword = Core_Array::get($aConfig, 'password');
		$this->_apiIkn = Core_Array::get($aConfig, 'ikn');
	}

	public function call(array $aParams)
	{
		$oLoginResponse = $this->_makeRequest('login', array(
			'Login' => $this->_apiLogin,
			'Password' => $this->_apiPassword
		));

		if (!isset($oLoginResponse->SessionId) || !$oLoginResponse->SessionId)
		{
			throw new Core_Exception('Не удалось авторизоваться, проверьте корректность данных.');
		}

		$aCourierData = array(
			'FIO' => Core_Array::get($aParams, 'name'),
			'Phone' => Core_Array::get($aParams, 'phone'),
			'IKN' => $this->_apiIkn,
			'SessionId' => $oLoginResponse->SessionId
		);

		$oResponse = $this->_makeRequest('/courier', $aCourierData);

		if (!isset($oResponse->CourierRequestRegistred) || !$oResponse->CourierRequestRegistred)
		{
			throw new Core_Exception('Не удалось вызвать курьера: ' . json_encode($oResponse));
		}
	}

	/**
	 * Выполняет запрос к API.
	 *
	 * @param  string  $resource
	 * @param  array  $data
	 * @return StdClass|NULL
	 */
	protected function _makeRequest($resource, $data)
	{
		$Core_Http = Core_Http::instance()
			->clear()
			->method('POST')
			->url($this->_apiUrl . $resource)
			->contentType('application/json')
			->additionalHeader('Accept', 'application/json')
			->rawData(json_encode($data))
			->timeout($this->_apiTimeout)
			->execute();

		return json_decode($Core_Http->getBody());
	}
}