<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

class Deliverystickers_File_Pdf extends Deliverystickers_File
{
	protected $_filePath;
	protected $_Stickers;

	static public function getXslName()
	{
		return 'DeliverysickersФормированиеЭтикеток';
	}

	public function __construct()
	{
		$this->_filePath = $this->_getFilePath();
		$this->_Stickers = array();
	}

	public function write(Shop_Order_Model $oShopOrder, Deliverystickers_Parcel_Model $oDeliverystickersParcel)
	{
		$this->_Stickers[] = array(
			'shop_order' => $oShopOrder,
			'parcel' => $oDeliverystickersParcel
		);

		return $this;
	}

	public function save()
	{
		$oFirstSticker = current($this->_Stickers);

		if (!$oFirstSticker)
		{
			throw new Core_Exception('Для формирования этикеток необходимо выбрать хотя бы один заказ.');
		}

		$oShop = $oFirstSticker['shop_order']->Shop;

		foreach ($this->_Stickers as $aSticker)
		{
			$sBarcode = $aSticker['parcel']->getBarcode();

			// Генерируем штрихкод
			$oDeliverystickersBarcodeGenerator = new Deliverystickers_Barcode_Generator;
			$sBarcodeImage = $oDeliverystickersBarcodeGenerator->generate($sBarcode);

			$oShopOrder = $aSticker['shop_order']
				->showXmlItems(TRUE)
				->showXmlProperties(TRUE)
				->addEntity(
					Core::factory('Core_Xml_Entity')
						->name('barcode')
						->value($sBarcode)
				)
				->addEntity(
					Core::factory('Core_Xml_Entity')
						->name('barcode_image')
						->value(
							'data:image/png;base64, ' . base64_encode($sBarcodeImage)
						)
				);

			$oShop->addEntity($oShopOrder);
		}

		$html = Xsl_Processor::instance()
			->xml($oShop->getXml())
			->xsl(
				Core_Entity::factory('Xsl')->getByName(self::getXslName())
			)
			->process();

		// file_put_contents($this->_filePath, $html);

		$oPdfActionConvert = new Pdf_Action_Convert;
		$oPdfActionConvert
			->html($html)
			->outputFile($this->_filePath)
			->font('OpenSans')
			->fontSize(10)
			->execute();

		return $this->_filePath;
	}

	protected function _getFilePath()
	{
		Core_File::mkdir($stickersDir = CMS_FOLDER . '/hostcmsfiles/deliverystickers/');
	
		do
		{
			$filePath = $stickersDir . str_replace(array('/', '+', '='), '', base64_encode(uniqid('', TRUE))) . '.pdf';
		}
		while (file_exists($filePath));

		return $filePath;
	}
}