<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

class Deliverystickers_Module extends Core_Module
{
	/**
	 * Версия модуля.
	 *
	 * @var string
	 */
	public $version = '0.1.0';

	/**
	 * Дата выпуска версии.
	 *
	 * @var string
	 */
	public $date = '2018-03-07';

	/**
	 * Идентификатор версии модуля.
	 *
	 * @var integer
	 */
	public $version_number = 1;

	/**
	 * Внутренний идентификатор модуля.
	 *
	 * @var integer
	 */
	protected $_module_id = 1337;

	/**
	 * Внутреннее название модуля.
	 *
	 * @var string
	 */
	protected $_internal_name = 'deliverystickers';

	/**
	 * Название модуля в меню ЦА.
	 *
	 * @var string
	 */
	protected $_client_name = 'Формирование этикеток';

	/**
	 * @var string
	 */
	protected $_admin_name = 'Формирование этикеток';

	/**
	 * Ссылка на сайт модуля.
	 *
	 * @var string
	 */
	protected $_module_site;

	/**
	 * Путь к модулю
	 *
	 * @var string
	 */
	protected $_module_path;

	/**
	 * Контроллер для работы с подсистемой Kad_Module.
	 * 
	 * @var Kad_Module_Controller
	 */
	protected $_controller;

	/**
	 * Формы модуля, используется при установке.
	 *
	 * @var array
	 */
	protected $_forms;

	/**
	 * Конструктор.
	 * 
	 * @return void
	 */
	public function __construct()
	{
		parent::__construct();

		// Меню в ЦА
		$this->menu = array(
			array(
				'sorting' => 0,
				'block' => 1,
				'ico' => 'fa fa-sticky-note',
				'name' => $this->_client_name,
				'href' => "/admin/{$this->_internal_name}/index.php",
				'onclick' => "$.adminLoad({path: '/admin/{$this->_internal_name}/index.php'}); return false"
			)
		);

		$this->_module_path = CMS_FOLDER . "/modules/{$this->_internal_name}/";
		$this->_module_site = 'http://kad.systems/shop/';
		$this->_controller = new Kad_Module_Controller($this->_module_id);

		Core_Event::attach('shop_order.onCallamount', function (Shop_Order_Model $oShopOrder) {
			return $oShopOrder->sum();
		});

		Core_Event::attach('shop_order.onCallfullname', function (Shop_Order_Model $oShopOrder) {
			return implode(' ', array_filter(array(
				$oShopOrder->surname,
				$oShopOrder->name,
				$oShopOrder->patronymic,
			))) ?: '----';
		});

		Core_Event::attach('shop_order.onCalldelivery', function (Shop_Order_Model $oShopOrder) {
			return $oShopOrder->Shop_Delivery->name ?: '----';
		});
	}

	/**
	 * Выполняет установку модуля.
	 * 
	 * Метод выполняется в момент включения флажка активности модуля.
	 * 
	 * @return void
	 */
	public function install()
	{
		/**
		 * Выполняется установочный SQL.
		 * 
		 * Метод проверяет существование файла install.sql,
		 * если такой существует, то он исполняется.
		 */
		$this->_installSQL();

		/**
		 * Установка подсистемы Kad_Module.
		 * 
		 * Устанавливает модуль, создает экземпляр контроллера.
		 */
		$this->_installKadModule();

		/**
		 * Создание форм.
		 */
		$this->_installForms();

		// Создаем XSL-шаблон
		if (!Core_Entity::factory('Xsl')->getByName(Deliverystickers_File_Pdf::getXslName()))
		{
			$oXsl = Core_Entity::factory('Xsl');
		  	$oXsl->name = Deliverystickers_File_Pdf::getXslName();
			$oXsl->save();

			$sXslContent = Core_File::read($this->_module_path . '/resources/transformation.xsl');
			$oXsl->saveXslFile($sXslContent);
		}

		/**
		 * Создание параметров подсистемы Kad_Module.
		 */
		$this->_setParams();

		Core_Message::show("Модуль «{$this->_client_name}» успешно установлен!");
	}

	/**
	 * Выполняет удаление модуля.
	 *
	 * Метод выполняется в момент отключения флажка активности модуля.
	 *
	 * @return void
	 */
	public function uninstall()
	{
		/**
		 * Удаление созданных форм.
		 */
		$this->_uninstallForms();

		Core_Message::show("Модуль «{$this->_client_name}» успешно удален!");
	}

	/**
	 * Установка подсистемы Kad_Module.
	 * 
	 * Устанавливает модуль, создает экземпляр контроллера.
	 * 
	 * @return void
	 */
	protected function _installKadModule()
	{
		Kad_Module_Controller::install();

		$this->_controller = new Kad_Module_Controller($this->_module_id);
	}

	/**
	 * Установка форм.
	 * 
	 * @return void
	 */
	protected function _installForms()
	{
		$oAdmin_Form = Core_Entity::factory('Admin_Form')->getByGuid('7FB1E3CD-FD30-4766-1360-4304B03DA0B3');

		if (is_null($oAdmin_Form))
		{
			/**
			 * Создаем значения Admin_Word_Value
			 */
			$oAdmin_Word = Core_Entity::factory('Admin_Word')->save();
			
			$oAdmin_Word_Value_RU = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_RU->admin_language_id = 1;
			$oAdmin_Word_Value_RU->name = 'Формирование этикеток';
			$oAdmin_Word->add($oAdmin_Word_Value_RU);
				
			$oAdmin_Word_Value_EN = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_EN->admin_language_id = 2;
			$oAdmin_Word_Value_EN->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_EN);
				
			$oAdmin_Word_Value_UA = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_UA->admin_language_id = 3;
			$oAdmin_Word_Value_UA->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_UA);
				
			/**
			 * Создаем форму
			 */
			$oAdmin_Form = Core_Entity::factory('Admin_Form');
			$oAdmin_Form->admin_word_id = $oAdmin_Word->id;
			$oAdmin_Form->on_page = 20;
			$oAdmin_Form->key_field = 'id';
			$oAdmin_Form->show_operations = 1;
			$oAdmin_Form->show_group_operations = 1;
			$oAdmin_Form->default_order_field = 'datetime';
			$oAdmin_Form->default_order_direction = 1;
			$oAdmin_Form->guid = '7FB1E3CD-FD30-4766-1360-4304B03DA0B3';
			$oAdmin_Form->save();

			/**
			 * Создаем поле формы
			 */
			$oAdmin_Word = Core_Entity::factory('Admin_Word')->save();
			
			$oAdmin_Word_Value_RU = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_RU->admin_language_id = 1;
			$oAdmin_Word_Value_RU->name = 'Номер заказа';
			$oAdmin_Word->add($oAdmin_Word_Value_RU);
				
			$oAdmin_Word_Value_EN = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_EN->admin_language_id = 2;
			$oAdmin_Word_Value_EN->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_EN);
				
			$oAdmin_Word_Value_UA = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_UA->admin_language_id = 3;
			$oAdmin_Word_Value_UA->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_UA);
				
			$oAdmin_Form_Field = Core_Entity::factory('Admin_Form_Field');
			$oAdmin_Form_Field->admin_word_id = $oAdmin_Word->id;
			$oAdmin_Form_Field->name = 'Invoice';
			$oAdmin_Form_Field->sorting = 1;
			$oAdmin_Form_Field->ico = '';
			$oAdmin_Form_Field->type = 1;
			$oAdmin_Form_Field->format = '';
			$oAdmin_Form_Field->allow_sorting = 0;
			$oAdmin_Form_Field->allow_filter = 0;
			$oAdmin_Form_Field->editable = 0;
			$oAdmin_Form_Field->filter_type = 0;
			$oAdmin_Form_Field->class = '';
			$oAdmin_Form_Field->width = '';
			$oAdmin_Form_Field->image = '';
			$oAdmin_Form_Field->link = '';
			$oAdmin_Form_Field->onclick = '';
			$oAdmin_Form_Field->list = '';
			$oAdmin_Form->add($oAdmin_Form_Field);

			/**
			 * Создаем поле формы
			 */
			$oAdmin_Word = Core_Entity::factory('Admin_Word')->save();
			
			$oAdmin_Word_Value_RU = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_RU->admin_language_id = 1;
			$oAdmin_Word_Value_RU->name = 'Имя';
			$oAdmin_Word->add($oAdmin_Word_Value_RU);
				
			$oAdmin_Word_Value_EN = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_EN->admin_language_id = 2;
			$oAdmin_Word_Value_EN->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_EN);
				
			$oAdmin_Word_Value_UA = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_UA->admin_language_id = 3;
			$oAdmin_Word_Value_UA->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_UA);
				
			$oAdmin_Form_Field = Core_Entity::factory('Admin_Form_Field');
			$oAdmin_Form_Field->admin_word_id = $oAdmin_Word->id;
			$oAdmin_Form_Field->name = 'fullname';
			$oAdmin_Form_Field->sorting = 2;
			$oAdmin_Form_Field->ico = '';
			$oAdmin_Form_Field->type = 1;
			$oAdmin_Form_Field->format = '';
			$oAdmin_Form_Field->allow_sorting = 0;
			$oAdmin_Form_Field->allow_filter = 0;
			$oAdmin_Form_Field->editable = 0;
			$oAdmin_Form_Field->filter_type = 0;
			$oAdmin_Form_Field->class = '';
			$oAdmin_Form_Field->width = '';
			$oAdmin_Form_Field->image = '';
			$oAdmin_Form_Field->link = '';
			$oAdmin_Form_Field->onclick = '';
			$oAdmin_Form_Field->list = '';
			$oAdmin_Form->add($oAdmin_Form_Field);

			/**
			 * Создаем поле формы
			 */
			$oAdmin_Word = Core_Entity::factory('Admin_Word')->save();
			
			$oAdmin_Word_Value_RU = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_RU->admin_language_id = 1;
			$oAdmin_Word_Value_RU->name = 'Сумма';
			$oAdmin_Word->add($oAdmin_Word_Value_RU);
				
			$oAdmin_Word_Value_EN = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_EN->admin_language_id = 2;
			$oAdmin_Word_Value_EN->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_EN);
				
			$oAdmin_Word_Value_UA = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_UA->admin_language_id = 3;
			$oAdmin_Word_Value_UA->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_UA);
				
			$oAdmin_Form_Field = Core_Entity::factory('Admin_Form_Field');
			$oAdmin_Form_Field->admin_word_id = $oAdmin_Word->id;
			$oAdmin_Form_Field->name = 'amount';
			$oAdmin_Form_Field->sorting = 3;
			$oAdmin_Form_Field->ico = '';
			$oAdmin_Form_Field->type = 1;
			$oAdmin_Form_Field->format = '';
			$oAdmin_Form_Field->allow_sorting = 0;
			$oAdmin_Form_Field->allow_filter = 0;
			$oAdmin_Form_Field->editable = 0;
			$oAdmin_Form_Field->filter_type = 0;
			$oAdmin_Form_Field->class = '';
			$oAdmin_Form_Field->width = '';
			$oAdmin_Form_Field->image = '';
			$oAdmin_Form_Field->link = '';
			$oAdmin_Form_Field->onclick = '';
			$oAdmin_Form_Field->list = '';
			$oAdmin_Form->add($oAdmin_Form_Field);

			/**
			 * Создаем поле формы
			 */
			$oAdmin_Word = Core_Entity::factory('Admin_Word')->save();
			
			$oAdmin_Word_Value_RU = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_RU->admin_language_id = 1;
			$oAdmin_Word_Value_RU->name = 'Дата';
			$oAdmin_Word->add($oAdmin_Word_Value_RU);
				
			$oAdmin_Word_Value_EN = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_EN->admin_language_id = 2;
			$oAdmin_Word_Value_EN->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_EN);
				
			$oAdmin_Word_Value_UA = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_UA->admin_language_id = 3;
			$oAdmin_Word_Value_UA->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_UA);
				
			$oAdmin_Form_Field = Core_Entity::factory('Admin_Form_Field');
			$oAdmin_Form_Field->admin_word_id = $oAdmin_Word->id;
			$oAdmin_Form_Field->name = 'datetime';
			$oAdmin_Form_Field->sorting = 4;
			$oAdmin_Form_Field->ico = '';
			$oAdmin_Form_Field->type = 1;
			$oAdmin_Form_Field->format = '';
			$oAdmin_Form_Field->allow_sorting = 1;
			$oAdmin_Form_Field->allow_filter = 0;
			$oAdmin_Form_Field->editable = 0;
			$oAdmin_Form_Field->filter_type = 0;
			$oAdmin_Form_Field->class = '';
			$oAdmin_Form_Field->width = '';
			$oAdmin_Form_Field->image = '';
			$oAdmin_Form_Field->link = '';
			$oAdmin_Form_Field->onclick = '';
			$oAdmin_Form_Field->list = '';
			$oAdmin_Form->add($oAdmin_Form_Field);

			/**
			 * Создаем поле формы
			 */
			$oAdmin_Word = Core_Entity::factory('Admin_Word')->save();
			
			$oAdmin_Word_Value_RU = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_RU->admin_language_id = 1;
			$oAdmin_Word_Value_RU->name = 'Доставка';
			$oAdmin_Word->add($oAdmin_Word_Value_RU);
				
			$oAdmin_Word_Value_EN = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_EN->admin_language_id = 2;
			$oAdmin_Word_Value_EN->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_EN);
				
			$oAdmin_Word_Value_UA = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_UA->admin_language_id = 3;
			$oAdmin_Word_Value_UA->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_UA);
				
			$oAdmin_Form_Field = Core_Entity::factory('Admin_Form_Field');
			$oAdmin_Form_Field->admin_word_id = $oAdmin_Word->id;
			$oAdmin_Form_Field->name = 'delivery';
			$oAdmin_Form_Field->sorting = 5;
			$oAdmin_Form_Field->ico = '';
			$oAdmin_Form_Field->type = 1;
			$oAdmin_Form_Field->format = '';
			$oAdmin_Form_Field->allow_sorting = 1;
			$oAdmin_Form_Field->allow_filter = 0;
			$oAdmin_Form_Field->editable = 0;
			$oAdmin_Form_Field->filter_type = 0;
			$oAdmin_Form_Field->class = '';
			$oAdmin_Form_Field->width = '';
			$oAdmin_Form_Field->image = '';
			$oAdmin_Form_Field->link = '';
			$oAdmin_Form_Field->onclick = '';
			$oAdmin_Form_Field->list = '';
			$oAdmin_Form->add($oAdmin_Form_Field);

			/**
			 * Создаем действие формы
			 */
			$oAdmin_Word = Core_Entity::factory('Admin_Word')->save();
			
			$oAdmin_Word_Value_RU = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_RU->admin_language_id = 1;
			$oAdmin_Word_Value_RU->name = 'Сформировать';
			$oAdmin_Word->add($oAdmin_Word_Value_RU);
				
			$oAdmin_Word_Value_EN = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_EN->admin_language_id = 2;
			$oAdmin_Word_Value_EN->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_EN);
				
			$oAdmin_Word_Value_UA = Core_Entity::factory('Admin_Word_Value');
			$oAdmin_Word_Value_UA->admin_language_id = 3;
			$oAdmin_Word_Value_UA->name = '';
			$oAdmin_Word->add($oAdmin_Word_Value_UA);
				
			$oAdmin_Form_Action = Core_Entity::factory('Admin_Form_Action');
			$oAdmin_Form_Action->admin_word_id = $oAdmin_Word->id;
			$oAdmin_Form_Action->name = 'process';
			$oAdmin_Form_Action->picture = '/admin/images/apply.gif';
			$oAdmin_Form_Action->icon = 'fa fa-check';
			$oAdmin_Form_Action->color = 'blue';
			$oAdmin_Form_Action->single = '0';
			$oAdmin_Form_Action->group = '1';
			$oAdmin_Form_Action->sorting = '0';
			$oAdmin_Form_Action->dataset = '-1';
			$oAdmin_Form_Action->confirm = '0';
			$oAdmin_Form->add($oAdmin_Form_Action);
}

		$this->_controller->set('admin_form', $oAdmin_Form->id);
	}

	/**
	 * Импорт таблиц модуля.
	 * 
	 * @return void
	 */
	protected function _installSQL()
	{
		Sql_Controller::instance()->execute("
			CREATE TABLE IF NOT EXISTS `deliverystickers_parcels` (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`code` double NOT NULL,
				`shop_order_id` int(11) unsigned DEFAULT NULL,
				`datetime` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
				`deleted` tinyint(1) NOT NULL DEFAULT '0',
				PRIMARY KEY (`id`),
				UNIQUE KEY `code` (`code`)
			) DEFAULT CHARSET=utf8;
		");
	}

	/**
	 * Удаление созданных форм
	 * 
	 * @return void
	 */
	protected function _uninstallForms()
	{
		$oAdminForm = Core_Entity::factory('Admin_Form', $this->_controller->get('admin_form'));
		
		if ($oAdminForm->id)
		{	
			$oAdminForm->delete();
		}
	}

	/**
	 * Установка параметров.
	 * 
	 * @param  array  $aParams
	 * @return void
	 */
	protected function _setParams($aParams = array())
	{
		$aParams['version'] = $this->version;
		$aParams['version_number'] = $this->version_number;
		$aParams['internal_name'] = $this->_internal_name;
		$aParams['client_name'] = $this->_client_name;
		$aParams['admin_name'] = $this->_admin_name;
		$aParams['module_site'] = $this->_module_site;
		
		foreach ($aParams as $key => $value)
		{
			$this->_controller->set($key, $value);
		}	
	}
}