<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
 * Базовый класс для действия над PDF-файлом.
 */
abstract class Pdf_Action extends Core_Servant_Properties
{
	/**
	 * Объект mPDF.
	 *
	 * @var \mPdf
	 */
	protected $_mpdf = NULL;

	/**
	 * Конструктор.
	 *
	 * @return void
	 */
	public function __construct()
	{
		parent::__construct();

		$prevLevel = error_reporting(E_ERROR);

		// Подключаем библиотеку
		require_once __DIR__ . '/vendor/mpdf/vendor/autoload.php';
		require_once __DIR__ . '/vendor/mpdf/mpdf.php';

		// Инициализируем объект
		$this->_mpdf = new mPDF;

		error_reporting($prevLevel);

		// Прикрепляем некоторые нестандартные шрифты
		$aFonts = array(
			'opensans' => array(
				'R' => '../../fonts/OpenSans/OpenSans-Regular.ttf',
				'B' => '../../fonts/OpenSans/OpenSans-Bold.ttf',
			)
		);

		$this->attachFonts($aFonts);
	}

	/**
	 * Прикрепляет нестандартные шрифты.
	 *
	 * @see http://stackoverflow.com/q/17586409/6734959
	 *
	 * @param  array  $aFonts
	 * @return self
	 */
	public function attachFonts($aFonts)
	{
		foreach ($aFonts as $fontName => $aFontStyles)
		{
			// Add to fontdata array
			$this->_mpdf->fontdata[$fontName] = $aFontStyles;

			// Add to available fonts array
			foreach (array('R', 'B', 'I', 'BI') as $style)
			{
				if (isset($aFontStyles[$style]) && $aFontStyles[$style])
				{
					// Warning: no suffix for regular style! hours wasted: 
					$this->_mpdf->available_unifonts[] = $fontName . trim($style, 'R');
				}
			}
		}

		$this->_mpdf->default_available_fonts = $this->_mpdf->available_unifonts;

		return $this;
	}

	/**
	 * Обертка для выполнения действия.
	 *
	 * @return self
	 */
	public function execute()
	{
		$prevLevel = error_reporting(E_ERROR);

		$this->_execute();

		error_reporting($prevLevel);

		return $this;
	}

	/**
	 * Выполняет действие.
	 *
	 * @return void
	 */
	abstract protected function _execute();
}