<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
 * Базовый контроллер модуля.
 *
 * @author KAD Systems (©) 2017 
 */
class Pdf_Controller
{
	/**
	 * The singleton instances.
	 * @var mixed
	 */
	static public $instance = NULL;

	/**
	 * Config array
	 * @var array
	 */
	static protected $_aConfig = NULL;

	/**
	 * Register an existing instance as a singleton.
	 * @return object
	 */
	static public function instance()
	{
		if (is_null(self::$instance))
		{
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Конструктор.
	 *
	 * @return void
	 */
	protected function __construct()
	{
		parent::__construct();

		self::getConfig();
	}

	/**
	 * Возвращает настройки модуля.
	 *
	 * @return array
	 */
	public function getConfig()
	{
		if (is_null(self::$_aConfig))
		{
			self::$_aConfig = Core_Config::instance()->get('pdf_config', array()) + array(
				
			);
		}

		return self::$_aConfig;
	}

	/**
	 * Прикрепляет наблюдатели для отправки счета в виде PDF-файла.
	 *
	 * @return void
	 */
	public function attachPaymentHandlerObserver()
	{
		Core_Event::attach('Shop_Payment_System_Handler.onBeforeSendSiteuserEmail', array('Pdf_Observers_Shop_Payment_System_Handler', 'onBeforeSendSiteuserEmail'));
		Core_Event::attach('Shop_Payment_System_Handler.onAfterSendSiteuserEmail',
			array('Pdf_Observers_Shop_Payment_System_Handler', 'onAfterSendSiteuserEmail'));
	}

	/**
	 * Открепляеи наблюдатели для отправки счета в виде PDF-файла.
	 *
	 * @return void
	 */
	public function detachPaymentHandlerObserver()
	{
		Core_Event::detach('Shop_Payment_System_Handler.onBeforeSendSiteuserEmail', array('Pdf_Observers_Shop_Payment_System_Handler', 'onBeforeSendSiteuserEmail'));
		Core_Event::detach('Shop_Payment_System_Handler.onAfterSendSiteuserEmail',
			array('Pdf_Observers_Shop_Payment_System_Handler', 'onAfterSendSiteuserEmail'));
	}

	/**
	 * Прикрепляет наблюдатели.
	 *
	 * @return void
	 */
	public function attachObservers()
	{
		$aConfig = $this->getConfig();

		if ($aConfig['observers_payment_handler'])
		{
			$this->attachPaymentHandlerObserver();
		}
	}

	/**
	 * Открепляет наблюдатели.
	 *
	 * @return void
	 */
	public function detachObservers()
	{
		if ($aConfig['observers_payment_handler'])
		{
			$this->detachPaymentHandlerObserver();
		}
	}
}