<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
 * Прикрепляет PDF-файл счета.
 *
 * @author KAD Systems (©) 2017 
 */
class Pdf_Observers_Shop_Payment_System_Handler
{
	/**
	 * Свойство для хранения пути ко временному файлу.
	 *
	 * @var string
	 */
	static protected $_pdfFile;

	/**
	 * Событие до отправки письма покупателю.
	 * 
	 * @param  Shop_Payment_System_Handler  $oShopPaymentSystemHandler
	 * @param  array  $aArgs
	 * @return void
	 */
	static public function onBeforeSendSiteuserEmail(Shop_Payment_System_Handler $oShopPaymentSystemHandler, array $aArgs)
	{
		if ($oShopPaymentSystemHandler->getShopOrder()->paid)
		{
			return;
		}

		// Получаем текст счета
		$sInvoice = $oShopPaymentSystemHandler->getInvoice();

		// Генерируем PDF-файл
		$pdfFile = CMS_FOLDER . TMP_DIR . uniqid() . '.pdf';

		$oMpdfController = new Pdf_Convert_Controller;
		$oMpdfController
			->convertToFile($sInvoice, $pdfFile);

		// Сохраняем имя временного файла
		self::$_pdfFile = $pdfFile;

		// Прикрепляем PDF-файл к письму
		$oCoreMail = $aArgs[0];
		$oCoreMail
			->attach(array(
				'filepath' => $pdfFile,
				'filename' => 'invoice.pdf',
			));
	}

	/**
	 * Событие после отправки письма покупателю.
	 * 
	 * @param  Shop_Payment_System_Handler  $oShopPaymentSystemHandler
	 * @param  array  $aArgs
	 * @return void
	 */
	static public function onAfterSendSiteuserEmail(Shop_Payment_System_Handler $oShopPaymentSystemHandler, array $aArgs)
	{
		try {
			// Удаляем временный файл
			Core_File::delete(self::$_pdfFile);
			self::$_pdfFile = NULL;
		}
		catch (\Exception $e)
		{
			// Этот блок выполнится, если произойдет ошибка при удалении временного PDF-файла,
			// в данном случае никаких действий не трубется, просто пропускаем такую ситуацтю.
		}
	}
}